Documentation
¶
Overview ¶
Package versions is a reverse proxy.
It translates gRPC into RESTful JSON APIs.
Index ¶
- func RegisterVersionsHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
- func RegisterVersionsHandlerClient(ctx context.Context, mux *runtime.ServeMux, client VersionsClient) error
- func RegisterVersionsHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, ...) (err error)
- func RegisterVersionsServer(s *grpc.Server, srv VersionsServer)
- type Application
- func (*Application) Descriptor() ([]byte, []int)
- func (m *Application) GetCreatedAt() string
- func (m *Application) GetId() string
- func (m *Application) GetName() string
- func (m *Application) GetUpdatedAt() string
- func (*Application) ProtoMessage()
- func (m *Application) Reset()
- func (m *Application) String() string
- func (m *Application) XXX_DiscardUnknown()
- func (m *Application) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Application) XXX_Merge(src proto.Message)
- func (m *Application) XXX_Size() int
- func (m *Application) XXX_Unmarshal(b []byte) error
- type ApplicationRequest
- func (*ApplicationRequest) Descriptor() ([]byte, []int)
- func (m *ApplicationRequest) GetApplication() *Application
- func (m *ApplicationRequest) GetApplicationId() string
- func (m *ApplicationRequest) GetId() string
- func (m *ApplicationRequest) GetLimit() int32
- func (m *ApplicationRequest) GetOffset() int32
- func (*ApplicationRequest) ProtoMessage()
- func (m *ApplicationRequest) Reset()
- func (m *ApplicationRequest) String() string
- func (m *ApplicationRequest) XXX_DiscardUnknown()
- func (m *ApplicationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *ApplicationRequest) XXX_Merge(src proto.Message)
- func (m *ApplicationRequest) XXX_Size() int
- func (m *ApplicationRequest) XXX_Unmarshal(b []byte) error
- type ApplicationResponse
- func (*ApplicationResponse) Descriptor() ([]byte, []int)
- func (m *ApplicationResponse) GetApplication() *Application
- func (m *ApplicationResponse) GetApplications() []*Application
- func (m *ApplicationResponse) GetLimit() int32
- func (m *ApplicationResponse) GetOffset() int32
- func (*ApplicationResponse) ProtoMessage()
- func (m *ApplicationResponse) Reset()
- func (m *ApplicationResponse) String() string
- func (m *ApplicationResponse) XXX_DiscardUnknown()
- func (m *ApplicationResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *ApplicationResponse) XXX_Merge(src proto.Message)
- func (m *ApplicationResponse) XXX_Size() int
- func (m *ApplicationResponse) XXX_Unmarshal(b []byte) error
- type Download
- func (*Download) Descriptor() ([]byte, []int)
- func (m *Download) GetArch() string
- func (m *Download) GetContentType() string
- func (m *Download) GetCreatedAt() string
- func (m *Download) GetData() []byte
- func (m *Download) GetExtension() string
- func (m *Download) GetFilename() string
- func (m *Download) GetFormat() string
- func (m *Download) GetId() int32
- func (m *Download) GetOs() string
- func (m *Download) GetProtocol() string
- func (m *Download) GetStorageType() string
- func (m *Download) GetTotalDownloads() int32
- func (m *Download) GetUpdatedAt() string
- func (m *Download) GetVersionId() int32
- func (*Download) ProtoMessage()
- func (m *Download) Reset()
- func (m *Download) String() string
- func (m *Download) XXX_DiscardUnknown()
- func (m *Download) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Download) XXX_Merge(src proto.Message)
- func (m *Download) XXX_Size() int
- func (m *Download) XXX_Unmarshal(b []byte) error
- type DownloadRequest
- func (*DownloadRequest) Descriptor() ([]byte, []int)
- func (m *DownloadRequest) GetData() []byte
- func (m *DownloadRequest) GetDownload() *Download
- func (m *DownloadRequest) GetDownloadId() int32
- func (m *DownloadRequest) GetId() int32
- func (m *DownloadRequest) GetLimit() int32
- func (m *DownloadRequest) GetOffset() int32
- func (m *DownloadRequest) GetVersionId() string
- func (*DownloadRequest) ProtoMessage()
- func (m *DownloadRequest) Reset()
- func (m *DownloadRequest) String() string
- func (m *DownloadRequest) XXX_DiscardUnknown()
- func (m *DownloadRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *DownloadRequest) XXX_Merge(src proto.Message)
- func (m *DownloadRequest) XXX_Size() int
- func (m *DownloadRequest) XXX_Unmarshal(b []byte) error
- type DownloadResponse
- func (*DownloadResponse) Descriptor() ([]byte, []int)
- func (m *DownloadResponse) GetDownload() *Download
- func (m *DownloadResponse) GetDownloads() []*Download
- func (m *DownloadResponse) GetLimit() int32
- func (m *DownloadResponse) GetOffset() int32
- func (*DownloadResponse) ProtoMessage()
- func (m *DownloadResponse) Reset()
- func (m *DownloadResponse) String() string
- func (m *DownloadResponse) XXX_DiscardUnknown()
- func (m *DownloadResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *DownloadResponse) XXX_Merge(src proto.Message)
- func (m *DownloadResponse) XXX_Size() int
- func (m *DownloadResponse) XXX_Unmarshal(b []byte) error
- type ServiceInfoRequest
- func (*ServiceInfoRequest) Descriptor() ([]byte, []int)
- func (*ServiceInfoRequest) ProtoMessage()
- func (m *ServiceInfoRequest) Reset()
- func (m *ServiceInfoRequest) String() string
- func (m *ServiceInfoRequest) XXX_DiscardUnknown()
- func (m *ServiceInfoRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *ServiceInfoRequest) XXX_Merge(src proto.Message)
- func (m *ServiceInfoRequest) XXX_Size() int
- func (m *ServiceInfoRequest) XXX_Unmarshal(b []byte) error
- type ServiceInfoResponse
- func (*ServiceInfoResponse) Descriptor() ([]byte, []int)
- func (m *ServiceInfoResponse) GetBuild() string
- func (m *ServiceInfoResponse) GetBuiltAt() string
- func (m *ServiceInfoResponse) GetVersion() string
- func (*ServiceInfoResponse) ProtoMessage()
- func (m *ServiceInfoResponse) Reset()
- func (m *ServiceInfoResponse) String() string
- func (m *ServiceInfoResponse) XXX_DiscardUnknown()
- func (m *ServiceInfoResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *ServiceInfoResponse) XXX_Merge(src proto.Message)
- func (m *ServiceInfoResponse) XXX_Size() int
- func (m *ServiceInfoResponse) XXX_Unmarshal(b []byte) error
- type Version
- func (*Version) Descriptor() ([]byte, []int)
- func (m *Version) GetApplication() *Application
- func (m *Version) GetApplicationId() string
- func (m *Version) GetCreatedAt() string
- func (m *Version) GetId() int32
- func (m *Version) GetMajor() string
- func (m *Version) GetMinor() string
- func (m *Version) GetName() string
- func (m *Version) GetRevision() string
- func (m *Version) GetStable() bool
- func (m *Version) GetUpdatedAt() string
- func (*Version) ProtoMessage()
- func (m *Version) Reset()
- func (m *Version) String() string
- func (m *Version) XXX_DiscardUnknown()
- func (m *Version) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *Version) XXX_Merge(src proto.Message)
- func (m *Version) XXX_Size() int
- func (m *Version) XXX_Unmarshal(b []byte) error
- type VersionRequest
- func (*VersionRequest) Descriptor() ([]byte, []int)
- func (m *VersionRequest) GetApplicationId() string
- func (m *VersionRequest) GetId() int32
- func (m *VersionRequest) GetLimit() int32
- func (m *VersionRequest) GetOffset() int32
- func (m *VersionRequest) GetVersion() *Version
- func (m *VersionRequest) GetVersionId() int32
- func (*VersionRequest) ProtoMessage()
- func (m *VersionRequest) Reset()
- func (m *VersionRequest) String() string
- func (m *VersionRequest) XXX_DiscardUnknown()
- func (m *VersionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *VersionRequest) XXX_Merge(src proto.Message)
- func (m *VersionRequest) XXX_Size() int
- func (m *VersionRequest) XXX_Unmarshal(b []byte) error
- type VersionResponse
- func (*VersionResponse) Descriptor() ([]byte, []int)
- func (m *VersionResponse) GetLimit() int32
- func (m *VersionResponse) GetOffset() int32
- func (m *VersionResponse) GetVersion() *Version
- func (m *VersionResponse) GetVersions() []*Version
- func (*VersionResponse) ProtoMessage()
- func (m *VersionResponse) Reset()
- func (m *VersionResponse) String() string
- func (m *VersionResponse) XXX_DiscardUnknown()
- func (m *VersionResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
- func (dst *VersionResponse) XXX_Merge(src proto.Message)
- func (m *VersionResponse) XXX_Size() int
- func (m *VersionResponse) XXX_Unmarshal(b []byte) error
- type VersionsClient
- type VersionsServer
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func RegisterVersionsHandler ¶
func RegisterVersionsHandler(ctx context.Context, mux *runtime.ServeMux, conn *grpc.ClientConn) error
RegisterVersionsHandler registers the http handlers for service Versions to "mux". The handlers forward requests to the grpc endpoint over "conn".
func RegisterVersionsHandlerClient ¶
func RegisterVersionsHandlerClient(ctx context.Context, mux *runtime.ServeMux, client VersionsClient) error
RegisterVersionsHandlerClient registers the http handlers for service Versions to "mux". The handlers forward requests to the grpc endpoint over the given implementation of "VersionsClient". Note: the gRPC framework executes interceptors within the gRPC handler. If the passed in "VersionsClient" doesn't go through the normal gRPC flow (creating a gRPC client etc.) then it will be up to the passed in "VersionsClient" to call the correct interceptors.
func RegisterVersionsHandlerFromEndpoint ¶
func RegisterVersionsHandlerFromEndpoint(ctx context.Context, mux *runtime.ServeMux, endpoint string, opts []grpc.DialOption) (err error)
RegisterVersionsHandlerFromEndpoint is same as RegisterVersionsHandler but automatically dials to "endpoint" and closes the connection when "ctx" gets done.
func RegisterVersionsServer ¶
func RegisterVersionsServer(s *grpc.Server, srv VersionsServer)
Types ¶
type Application ¶
type Application struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
Name string `protobuf:"bytes,2,opt,name=name,proto3" json:"name,omitempty"`
UpdatedAt string `protobuf:"bytes,3,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
CreatedAt string `protobuf:"bytes,4,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Application) Descriptor ¶
func (*Application) Descriptor() ([]byte, []int)
func (*Application) GetCreatedAt ¶
func (m *Application) GetCreatedAt() string
func (*Application) GetId ¶
func (m *Application) GetId() string
func (*Application) GetName ¶
func (m *Application) GetName() string
func (*Application) GetUpdatedAt ¶
func (m *Application) GetUpdatedAt() string
func (*Application) ProtoMessage ¶
func (*Application) ProtoMessage()
func (*Application) Reset ¶
func (m *Application) Reset()
func (*Application) String ¶
func (m *Application) String() string
func (*Application) XXX_DiscardUnknown ¶
func (m *Application) XXX_DiscardUnknown()
func (*Application) XXX_Marshal ¶
func (m *Application) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*Application) XXX_Merge ¶
func (dst *Application) XXX_Merge(src proto.Message)
func (*Application) XXX_Size ¶
func (m *Application) XXX_Size() int
func (*Application) XXX_Unmarshal ¶
func (m *Application) XXX_Unmarshal(b []byte) error
type ApplicationRequest ¶
type ApplicationRequest struct {
Id string `protobuf:"bytes,1,opt,name=id,proto3" json:"id,omitempty"`
ApplicationId string `protobuf:"bytes,2,opt,name=application_id,json=applicationId,proto3" json:"application_id,omitempty"`
Application *Application `protobuf:"bytes,3,opt,name=application,proto3" json:"application,omitempty"`
Limit int32 `protobuf:"varint,4,opt,name=limit,proto3" json:"limit,omitempty"`
Offset int32 `protobuf:"varint,5,opt,name=offset,proto3" json:"offset,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*ApplicationRequest) Descriptor ¶
func (*ApplicationRequest) Descriptor() ([]byte, []int)
func (*ApplicationRequest) GetApplication ¶
func (m *ApplicationRequest) GetApplication() *Application
func (*ApplicationRequest) GetApplicationId ¶
func (m *ApplicationRequest) GetApplicationId() string
func (*ApplicationRequest) GetId ¶
func (m *ApplicationRequest) GetId() string
func (*ApplicationRequest) GetLimit ¶
func (m *ApplicationRequest) GetLimit() int32
func (*ApplicationRequest) GetOffset ¶
func (m *ApplicationRequest) GetOffset() int32
func (*ApplicationRequest) ProtoMessage ¶
func (*ApplicationRequest) ProtoMessage()
func (*ApplicationRequest) Reset ¶
func (m *ApplicationRequest) Reset()
func (*ApplicationRequest) String ¶
func (m *ApplicationRequest) String() string
func (*ApplicationRequest) XXX_DiscardUnknown ¶
func (m *ApplicationRequest) XXX_DiscardUnknown()
func (*ApplicationRequest) XXX_Marshal ¶
func (m *ApplicationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ApplicationRequest) XXX_Merge ¶
func (dst *ApplicationRequest) XXX_Merge(src proto.Message)
func (*ApplicationRequest) XXX_Size ¶
func (m *ApplicationRequest) XXX_Size() int
func (*ApplicationRequest) XXX_Unmarshal ¶
func (m *ApplicationRequest) XXX_Unmarshal(b []byte) error
type ApplicationResponse ¶
type ApplicationResponse struct {
Application *Application `protobuf:"bytes,1,opt,name=application,proto3" json:"application,omitempty"`
Applications []*Application `protobuf:"bytes,2,rep,name=applications,proto3" json:"applications,omitempty"`
Limit int32 `protobuf:"varint,3,opt,name=limit,proto3" json:"limit,omitempty"`
Offset int32 `protobuf:"varint,4,opt,name=offset,proto3" json:"offset,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*ApplicationResponse) Descriptor ¶
func (*ApplicationResponse) Descriptor() ([]byte, []int)
func (*ApplicationResponse) GetApplication ¶
func (m *ApplicationResponse) GetApplication() *Application
func (*ApplicationResponse) GetApplications ¶
func (m *ApplicationResponse) GetApplications() []*Application
func (*ApplicationResponse) GetLimit ¶
func (m *ApplicationResponse) GetLimit() int32
func (*ApplicationResponse) GetOffset ¶
func (m *ApplicationResponse) GetOffset() int32
func (*ApplicationResponse) ProtoMessage ¶
func (*ApplicationResponse) ProtoMessage()
func (*ApplicationResponse) Reset ¶
func (m *ApplicationResponse) Reset()
func (*ApplicationResponse) String ¶
func (m *ApplicationResponse) String() string
func (*ApplicationResponse) XXX_DiscardUnknown ¶
func (m *ApplicationResponse) XXX_DiscardUnknown()
func (*ApplicationResponse) XXX_Marshal ¶
func (m *ApplicationResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ApplicationResponse) XXX_Merge ¶
func (dst *ApplicationResponse) XXX_Merge(src proto.Message)
func (*ApplicationResponse) XXX_Size ¶
func (m *ApplicationResponse) XXX_Size() int
func (*ApplicationResponse) XXX_Unmarshal ¶
func (m *ApplicationResponse) XXX_Unmarshal(b []byte) error
type Download ¶
type Download struct {
Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
VersionId int32 `protobuf:"varint,2,opt,name=version_id,json=versionId,proto3" json:"version_id,omitempty"`
StorageType string `protobuf:"bytes,3,opt,name=storage_type,json=storageType,proto3" json:"storage_type,omitempty"`
Format string `protobuf:"bytes,4,opt,name=format,proto3" json:"format,omitempty"`
Protocol string `protobuf:"bytes,5,opt,name=protocol,proto3" json:"protocol,omitempty"`
Os string `protobuf:"bytes,6,opt,name=os,proto3" json:"os,omitempty"`
Arch string `protobuf:"bytes,7,opt,name=arch,proto3" json:"arch,omitempty"`
Filename string `protobuf:"bytes,8,opt,name=filename,proto3" json:"filename,omitempty"`
Extension string `protobuf:"bytes,9,opt,name=extension,proto3" json:"extension,omitempty"`
ContentType string `protobuf:"bytes,10,opt,name=content_type,json=contentType,proto3" json:"content_type,omitempty"`
TotalDownloads int32 `protobuf:"varint,11,opt,name=total_downloads,json=totalDownloads,proto3" json:"total_downloads,omitempty"`
UpdatedAt string `protobuf:"bytes,12,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
CreatedAt string `protobuf:"bytes,13,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
Data []byte `protobuf:"bytes,14,opt,name=data,proto3" json:"data,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Download) Descriptor ¶
func (*Download) GetContentType ¶
func (*Download) GetCreatedAt ¶
func (*Download) GetExtension ¶
func (*Download) GetFilename ¶
func (*Download) GetProtocol ¶
func (*Download) GetStorageType ¶
func (*Download) GetTotalDownloads ¶
func (*Download) GetUpdatedAt ¶
func (*Download) GetVersionId ¶
func (*Download) ProtoMessage ¶
func (*Download) ProtoMessage()
func (*Download) XXX_DiscardUnknown ¶
func (m *Download) XXX_DiscardUnknown()
func (*Download) XXX_Marshal ¶
func (*Download) XXX_Unmarshal ¶
type DownloadRequest ¶
type DownloadRequest struct {
Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
DownloadId int32 `protobuf:"varint,2,opt,name=download_id,json=downloadId,proto3" json:"download_id,omitempty"`
Download *Download `protobuf:"bytes,3,opt,name=download,proto3" json:"download,omitempty"`
VersionId string `protobuf:"bytes,4,opt,name=version_id,json=versionId,proto3" json:"version_id,omitempty"`
Data []byte `protobuf:"bytes,5,opt,name=data,proto3" json:"data,omitempty"`
Limit int32 `protobuf:"varint,6,opt,name=limit,proto3" json:"limit,omitempty"`
Offset int32 `protobuf:"varint,7,opt,name=offset,proto3" json:"offset,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*DownloadRequest) Descriptor ¶
func (*DownloadRequest) Descriptor() ([]byte, []int)
func (*DownloadRequest) GetData ¶
func (m *DownloadRequest) GetData() []byte
func (*DownloadRequest) GetDownload ¶
func (m *DownloadRequest) GetDownload() *Download
func (*DownloadRequest) GetDownloadId ¶
func (m *DownloadRequest) GetDownloadId() int32
func (*DownloadRequest) GetId ¶
func (m *DownloadRequest) GetId() int32
func (*DownloadRequest) GetLimit ¶
func (m *DownloadRequest) GetLimit() int32
func (*DownloadRequest) GetOffset ¶
func (m *DownloadRequest) GetOffset() int32
func (*DownloadRequest) GetVersionId ¶
func (m *DownloadRequest) GetVersionId() string
func (*DownloadRequest) ProtoMessage ¶
func (*DownloadRequest) ProtoMessage()
func (*DownloadRequest) Reset ¶
func (m *DownloadRequest) Reset()
func (*DownloadRequest) String ¶
func (m *DownloadRequest) String() string
func (*DownloadRequest) XXX_DiscardUnknown ¶
func (m *DownloadRequest) XXX_DiscardUnknown()
func (*DownloadRequest) XXX_Marshal ¶
func (m *DownloadRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*DownloadRequest) XXX_Merge ¶
func (dst *DownloadRequest) XXX_Merge(src proto.Message)
func (*DownloadRequest) XXX_Size ¶
func (m *DownloadRequest) XXX_Size() int
func (*DownloadRequest) XXX_Unmarshal ¶
func (m *DownloadRequest) XXX_Unmarshal(b []byte) error
type DownloadResponse ¶
type DownloadResponse struct {
Download *Download `protobuf:"bytes,1,opt,name=download,proto3" json:"download,omitempty"`
Downloads []*Download `protobuf:"bytes,2,rep,name=downloads,proto3" json:"downloads,omitempty"`
Limit int32 `protobuf:"varint,3,opt,name=limit,proto3" json:"limit,omitempty"`
Offset int32 `protobuf:"varint,4,opt,name=offset,proto3" json:"offset,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*DownloadResponse) Descriptor ¶
func (*DownloadResponse) Descriptor() ([]byte, []int)
func (*DownloadResponse) GetDownload ¶
func (m *DownloadResponse) GetDownload() *Download
func (*DownloadResponse) GetDownloads ¶
func (m *DownloadResponse) GetDownloads() []*Download
func (*DownloadResponse) GetLimit ¶
func (m *DownloadResponse) GetLimit() int32
func (*DownloadResponse) GetOffset ¶
func (m *DownloadResponse) GetOffset() int32
func (*DownloadResponse) ProtoMessage ¶
func (*DownloadResponse) ProtoMessage()
func (*DownloadResponse) Reset ¶
func (m *DownloadResponse) Reset()
func (*DownloadResponse) String ¶
func (m *DownloadResponse) String() string
func (*DownloadResponse) XXX_DiscardUnknown ¶
func (m *DownloadResponse) XXX_DiscardUnknown()
func (*DownloadResponse) XXX_Marshal ¶
func (m *DownloadResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*DownloadResponse) XXX_Merge ¶
func (dst *DownloadResponse) XXX_Merge(src proto.Message)
func (*DownloadResponse) XXX_Size ¶
func (m *DownloadResponse) XXX_Size() int
func (*DownloadResponse) XXX_Unmarshal ¶
func (m *DownloadResponse) XXX_Unmarshal(b []byte) error
type ServiceInfoRequest ¶
type ServiceInfoRequest struct {
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*ServiceInfoRequest) Descriptor ¶
func (*ServiceInfoRequest) Descriptor() ([]byte, []int)
func (*ServiceInfoRequest) ProtoMessage ¶
func (*ServiceInfoRequest) ProtoMessage()
func (*ServiceInfoRequest) Reset ¶
func (m *ServiceInfoRequest) Reset()
func (*ServiceInfoRequest) String ¶
func (m *ServiceInfoRequest) String() string
func (*ServiceInfoRequest) XXX_DiscardUnknown ¶
func (m *ServiceInfoRequest) XXX_DiscardUnknown()
func (*ServiceInfoRequest) XXX_Marshal ¶
func (m *ServiceInfoRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ServiceInfoRequest) XXX_Merge ¶
func (dst *ServiceInfoRequest) XXX_Merge(src proto.Message)
func (*ServiceInfoRequest) XXX_Size ¶
func (m *ServiceInfoRequest) XXX_Size() int
func (*ServiceInfoRequest) XXX_Unmarshal ¶
func (m *ServiceInfoRequest) XXX_Unmarshal(b []byte) error
type ServiceInfoResponse ¶
type ServiceInfoResponse struct {
Version string `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
Build string `protobuf:"bytes,2,opt,name=build,proto3" json:"build,omitempty"`
BuiltAt string `protobuf:"bytes,3,opt,name=built_at,json=builtAt,proto3" json:"built_at,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*ServiceInfoResponse) Descriptor ¶
func (*ServiceInfoResponse) Descriptor() ([]byte, []int)
func (*ServiceInfoResponse) GetBuild ¶
func (m *ServiceInfoResponse) GetBuild() string
func (*ServiceInfoResponse) GetBuiltAt ¶
func (m *ServiceInfoResponse) GetBuiltAt() string
func (*ServiceInfoResponse) GetVersion ¶
func (m *ServiceInfoResponse) GetVersion() string
func (*ServiceInfoResponse) ProtoMessage ¶
func (*ServiceInfoResponse) ProtoMessage()
func (*ServiceInfoResponse) Reset ¶
func (m *ServiceInfoResponse) Reset()
func (*ServiceInfoResponse) String ¶
func (m *ServiceInfoResponse) String() string
func (*ServiceInfoResponse) XXX_DiscardUnknown ¶
func (m *ServiceInfoResponse) XXX_DiscardUnknown()
func (*ServiceInfoResponse) XXX_Marshal ¶
func (m *ServiceInfoResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*ServiceInfoResponse) XXX_Merge ¶
func (dst *ServiceInfoResponse) XXX_Merge(src proto.Message)
func (*ServiceInfoResponse) XXX_Size ¶
func (m *ServiceInfoResponse) XXX_Size() int
func (*ServiceInfoResponse) XXX_Unmarshal ¶
func (m *ServiceInfoResponse) XXX_Unmarshal(b []byte) error
type Version ¶
type Version struct {
Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
Major string `protobuf:"bytes,2,opt,name=major,proto3" json:"major,omitempty"`
Minor string `protobuf:"bytes,3,opt,name=minor,proto3" json:"minor,omitempty"`
Revision string `protobuf:"bytes,4,opt,name=revision,proto3" json:"revision,omitempty"`
Application *Application `protobuf:"bytes,5,opt,name=application,proto3" json:"application,omitempty"`
ApplicationId string `protobuf:"bytes,6,opt,name=application_id,json=applicationId,proto3" json:"application_id,omitempty"`
Name string `protobuf:"bytes,7,opt,name=name,proto3" json:"name,omitempty"`
Stable bool `protobuf:"varint,8,opt,name=stable,proto3" json:"stable,omitempty"`
UpdatedAt string `protobuf:"bytes,9,opt,name=updated_at,json=updatedAt,proto3" json:"updated_at,omitempty"`
CreatedAt string `protobuf:"bytes,10,opt,name=created_at,json=createdAt,proto3" json:"created_at,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*Version) Descriptor ¶
func (*Version) GetApplication ¶
func (m *Version) GetApplication() *Application
func (*Version) GetApplicationId ¶
func (*Version) GetCreatedAt ¶
func (*Version) GetRevision ¶
func (*Version) GetUpdatedAt ¶
func (*Version) ProtoMessage ¶
func (*Version) ProtoMessage()
func (*Version) XXX_DiscardUnknown ¶
func (m *Version) XXX_DiscardUnknown()
func (*Version) XXX_Marshal ¶
func (*Version) XXX_Unmarshal ¶
type VersionRequest ¶
type VersionRequest struct {
Id int32 `protobuf:"varint,1,opt,name=id,proto3" json:"id,omitempty"`
VersionId int32 `protobuf:"varint,2,opt,name=version_id,json=versionId,proto3" json:"version_id,omitempty"`
Version *Version `protobuf:"bytes,3,opt,name=version,proto3" json:"version,omitempty"`
ApplicationId string `protobuf:"bytes,4,opt,name=application_id,json=applicationId,proto3" json:"application_id,omitempty"`
Limit int32 `protobuf:"varint,5,opt,name=limit,proto3" json:"limit,omitempty"`
Offset int32 `protobuf:"varint,6,opt,name=offset,proto3" json:"offset,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*VersionRequest) Descriptor ¶
func (*VersionRequest) Descriptor() ([]byte, []int)
func (*VersionRequest) GetApplicationId ¶
func (m *VersionRequest) GetApplicationId() string
func (*VersionRequest) GetId ¶
func (m *VersionRequest) GetId() int32
func (*VersionRequest) GetLimit ¶
func (m *VersionRequest) GetLimit() int32
func (*VersionRequest) GetOffset ¶
func (m *VersionRequest) GetOffset() int32
func (*VersionRequest) GetVersion ¶
func (m *VersionRequest) GetVersion() *Version
func (*VersionRequest) GetVersionId ¶
func (m *VersionRequest) GetVersionId() int32
func (*VersionRequest) ProtoMessage ¶
func (*VersionRequest) ProtoMessage()
func (*VersionRequest) Reset ¶
func (m *VersionRequest) Reset()
func (*VersionRequest) String ¶
func (m *VersionRequest) String() string
func (*VersionRequest) XXX_DiscardUnknown ¶
func (m *VersionRequest) XXX_DiscardUnknown()
func (*VersionRequest) XXX_Marshal ¶
func (m *VersionRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*VersionRequest) XXX_Merge ¶
func (dst *VersionRequest) XXX_Merge(src proto.Message)
func (*VersionRequest) XXX_Size ¶
func (m *VersionRequest) XXX_Size() int
func (*VersionRequest) XXX_Unmarshal ¶
func (m *VersionRequest) XXX_Unmarshal(b []byte) error
type VersionResponse ¶
type VersionResponse struct {
Version *Version `protobuf:"bytes,1,opt,name=version,proto3" json:"version,omitempty"`
Versions []*Version `protobuf:"bytes,2,rep,name=versions,proto3" json:"versions,omitempty"`
Limit int32 `protobuf:"varint,3,opt,name=limit,proto3" json:"limit,omitempty"`
Offset int32 `protobuf:"varint,4,opt,name=offset,proto3" json:"offset,omitempty"`
XXX_NoUnkeyedLiteral struct{} `json:"-"`
XXX_unrecognized []byte `json:"-"`
XXX_sizecache int32 `json:"-"`
}
func (*VersionResponse) Descriptor ¶
func (*VersionResponse) Descriptor() ([]byte, []int)
func (*VersionResponse) GetLimit ¶
func (m *VersionResponse) GetLimit() int32
func (*VersionResponse) GetOffset ¶
func (m *VersionResponse) GetOffset() int32
func (*VersionResponse) GetVersion ¶
func (m *VersionResponse) GetVersion() *Version
func (*VersionResponse) GetVersions ¶
func (m *VersionResponse) GetVersions() []*Version
func (*VersionResponse) ProtoMessage ¶
func (*VersionResponse) ProtoMessage()
func (*VersionResponse) Reset ¶
func (m *VersionResponse) Reset()
func (*VersionResponse) String ¶
func (m *VersionResponse) String() string
func (*VersionResponse) XXX_DiscardUnknown ¶
func (m *VersionResponse) XXX_DiscardUnknown()
func (*VersionResponse) XXX_Marshal ¶
func (m *VersionResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error)
func (*VersionResponse) XXX_Merge ¶
func (dst *VersionResponse) XXX_Merge(src proto.Message)
func (*VersionResponse) XXX_Size ¶
func (m *VersionResponse) XXX_Size() int
func (*VersionResponse) XXX_Unmarshal ¶
func (m *VersionResponse) XXX_Unmarshal(b []byte) error
type VersionsClient ¶
type VersionsClient interface {
// Get service version and build info
Info(ctx context.Context, in *ServiceInfoRequest, opts ...grpc.CallOption) (*ServiceInfoResponse, error)
// Get version by ID
GetVersion(ctx context.Context, in *VersionRequest, opts ...grpc.CallOption) (*VersionResponse, error)
// Get applications versions
GetVersions(ctx context.Context, in *VersionRequest, opts ...grpc.CallOption) (*VersionResponse, error)
// Get applications latest version
GetLatestVersion(ctx context.Context, in *VersionRequest, opts ...grpc.CallOption) (*VersionResponse, error)
// Create new version
CreateVersion(ctx context.Context, in *Version, opts ...grpc.CallOption) (*VersionResponse, error)
// Update existing version
UpdateVersion(ctx context.Context, in *VersionRequest, opts ...grpc.CallOption) (*VersionResponse, error)
// Delete version
DeleteVersion(ctx context.Context, in *VersionRequest, opts ...grpc.CallOption) (*empty.Empty, error)
// Get applications list
GetApplications(ctx context.Context, in *ApplicationRequest, opts ...grpc.CallOption) (*ApplicationResponse, error)
// Get application details
GetApplication(ctx context.Context, in *ApplicationRequest, opts ...grpc.CallOption) (*ApplicationResponse, error)
// Create new application
CreateApplication(ctx context.Context, in *Application, opts ...grpc.CallOption) (*ApplicationResponse, error)
// Update existing application
UpdateApplication(ctx context.Context, in *ApplicationRequest, opts ...grpc.CallOption) (*ApplicationResponse, error)
// Delete application by ID
DeleteApplication(ctx context.Context, in *ApplicationRequest, opts ...grpc.CallOption) (*empty.Empty, error)
// Get downloads list
GetDownloads(ctx context.Context, in *DownloadRequest, opts ...grpc.CallOption) (*DownloadResponse, error)
// Get download details
GetDownload(ctx context.Context, in *DownloadRequest, opts ...grpc.CallOption) (*DownloadResponse, error)
// Create new download
// HTTP Fallback is handled in the service file download.go
// handleFallbackDownloads
//
// option (google.api.http) = {
// post: "/v1/versions/{version_id}/downloads"
// body: "*"
// };
CreateDownload(ctx context.Context, in *Download, opts ...grpc.CallOption) (*DownloadResponse, error)
// Get download file
// HTTP Fallback is handled in the service file download.go
// handleFallbackDownloads
//
// option (google.api.http) = {
// get: "/v1/downloads/{download_id}/file"
// };
GetDownloadFile(ctx context.Context, in *Download, opts ...grpc.CallOption) (*Download, error)
// Update existing download
UpdateDownload(ctx context.Context, in *DownloadRequest, opts ...grpc.CallOption) (*DownloadResponse, error)
// Delete download by ID
DeleteDownload(ctx context.Context, in *DownloadRequest, opts ...grpc.CallOption) (*empty.Empty, error)
}
VersionsClient is the client API for Versions service.
For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
func NewVersionsClient ¶
func NewVersionsClient(cc *grpc.ClientConn) VersionsClient
type VersionsServer ¶
type VersionsServer interface {
// Get service version and build info
Info(context.Context, *ServiceInfoRequest) (*ServiceInfoResponse, error)
// Get version by ID
GetVersion(context.Context, *VersionRequest) (*VersionResponse, error)
// Get applications versions
GetVersions(context.Context, *VersionRequest) (*VersionResponse, error)
// Get applications latest version
GetLatestVersion(context.Context, *VersionRequest) (*VersionResponse, error)
// Create new version
CreateVersion(context.Context, *Version) (*VersionResponse, error)
// Update existing version
UpdateVersion(context.Context, *VersionRequest) (*VersionResponse, error)
// Delete version
DeleteVersion(context.Context, *VersionRequest) (*empty.Empty, error)
// Get applications list
GetApplications(context.Context, *ApplicationRequest) (*ApplicationResponse, error)
// Get application details
GetApplication(context.Context, *ApplicationRequest) (*ApplicationResponse, error)
// Create new application
CreateApplication(context.Context, *Application) (*ApplicationResponse, error)
// Update existing application
UpdateApplication(context.Context, *ApplicationRequest) (*ApplicationResponse, error)
// Delete application by ID
DeleteApplication(context.Context, *ApplicationRequest) (*empty.Empty, error)
// Get downloads list
GetDownloads(context.Context, *DownloadRequest) (*DownloadResponse, error)
// Get download details
GetDownload(context.Context, *DownloadRequest) (*DownloadResponse, error)
// Create new download
// HTTP Fallback is handled in the service file download.go
// handleFallbackDownloads
//
// option (google.api.http) = {
// post: "/v1/versions/{version_id}/downloads"
// body: "*"
// };
CreateDownload(context.Context, *Download) (*DownloadResponse, error)
// Get download file
// HTTP Fallback is handled in the service file download.go
// handleFallbackDownloads
//
// option (google.api.http) = {
// get: "/v1/downloads/{download_id}/file"
// };
GetDownloadFile(context.Context, *Download) (*Download, error)
// Update existing download
UpdateDownload(context.Context, *DownloadRequest) (*DownloadResponse, error)
// Delete download by ID
DeleteDownload(context.Context, *DownloadRequest) (*empty.Empty, error)
}
VersionsServer is the server API for Versions service.